mplcursors – Interactive data selection cursors for Matplotlib
==============================================================

|PyPI| |Read the Docs| |Travis| |CodeCov|

.. |PyPI|
   image:: https://img.shields.io/pypi/v/mplcursors.svg
   :target: https://pypi.python.org/pypi/mplcursors
.. |Read the Docs|
   image:: https://readthedocs.org/projects/mplcursors/badge/?version=latest
   :target: http://mplcursors.readthedocs.io/en/latest/?badge=latest
.. |Travis|
   image:: https://travis-ci.org/anntzer/mplcursors.svg?branch=master
   :target: https://travis-ci.org/anntzer/mplcursors
.. |CodeCov|
   image:: https://codecov.io/gh/anntzer/mplcursors/master.svg
   :target: https://codecov.io/gh/anntzer/mplcursors

mplcursors provides interactive data selection cursors for Matplotlib_.  It is
inspired from mpldatacursor_, with a much simplified API.

mplcursors requires Python 3, and Matplotlib_\≥2.1.

Read the documentation on `readthedocs.org`_.

Install from PyPI with::

   python -mpip install mplcursors

or from Github with::

   python -mpip install git+https://github.com/anntzer/mplcursors

Run tests with pytest_\≥3.0.0.

.. _Matplotlib: http://matplotlib.org
.. _mpldatacursor: https://github.com/joferkington/mpldatacursor
.. _pytest: http://pytest.org
.. _readthedocs.org: https://mplcursors.readthedocs.org
